@@ -1,9 +1,6 @@
 comp2col <-
-function(dat, position.legend, palette, range) {
-    
-	color <- colorRampPalette(palette,space="rgb")(99)
-	
-	
+function(dat, position.legend, palette, range, border.col, fontfamily.legend) {
+    color <- colorRampPalette(palette,space="rgb")(99)
 	perc <-((dat$s - dat$c)/dat$c) * 100
 	
 	growth <- (dat$s / dat$c)
@@ -15,8 +12,11 @@ function(dat, position.legend, palette, range) {
 	log.growth <- log(growth)
 	
 	# edit perc
-	perc[perc==Inf] <- max(900, c(perc[perc!=Inf]))
-	perc[perc==0] <- min(-90, c(perc[perc!=0]))
+	perc.orig <- perc
+	
+    largeSign <- any(perc>1000) #to prevent legend scales > 1000
+    perc[perc > 900] <- 900
+ 	perc[perc < -90] <- -90
 	
 	range_lg <- range(log.growth)
 	
@@ -34,22 +34,32 @@ function(dat, position.legend, palette, range) {
     
     prettyP <- prettyP[prettyP > -100]
     
-	n <- length(prettyP)	
-
-	max_lg <- max(abs(log.growth))
+    perc2lg <- function(p) log((100+p)/100)
+    legColScale <- perc2lg(prettyP)
+    
+    if (!any(is.na(range))) {
+        max_lg <- max(abs(legColScale))
+    } else {
+        max_lg <- max(abs(log.growth))
+        if (max_lg==0) max_lg <- max(abs(legColScale))
+    }
+    
 	scale <- round(((log.growth/max_lg) *49)+50)
-	
-	perc2lg <- function(p) log((100+p)/100)
-	
-	
-	legColScale <- perc2lg(prettyP)
 	legColScale[legColScale < -max_lg] <- -max_lg
 	legColScale[legColScale > max_lg] <- max_lg
 	
 	legCol <- color[round(((legColScale/max_lg) *49)+50)]
 		
-	if (position.legend!="none") drawLegend(paste(prettyP, "%", sep=""), legCol,
-											position.legend=="bottom")
-	return (color[scale])
+	if (position.legend!="none") {
+        prettyString <- paste(prettyP, "%", sep="")
+        if (largeSign) {
+            lp <- prettyString[length(prettyString)]
+            prettyString[length(prettyString)] <- paste(">", lp)
+        }
+        
+        drawLegend(prettyString, legCol,
+											position.legend=="bottom", border.col, fontfamily.legend)
+	}
+	return (list(color[scale], range(prettyP), perc.orig))
 }
 
